@@ -10,6 +10,7 @@
  *               2012 Henry Gebhardt <hsggebhardt@gmail.com>
  *               2014 Peter <ombalaxitabou@users.sf.net>
  *               2014-2016 Andriy Grytsenko <andrej@rep.kiev.ua>
+ *               2020 TheZxcv <the.uint64.t@gmail.com>
  *
  * This file is a part of LXPanel project.
  *
@@ -863,11 +864,14 @@ static void volumealsa_build_popup_window(GtkWidget *p)
 {
     VolumeALSAPlugin * vol = lxpanel_plugin_get_data(p);
 
+    gdouble dpi = gdk_screen_get_resolution(gdk_screen_get_default());
+    gint scaling_factor = (int) ceil(dpi / 96);
+
     /* Create a new window. */
     vol->popup_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_decorated(GTK_WINDOW(vol->popup_window), FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(vol->popup_window), 5);
-    gtk_window_set_default_size(GTK_WINDOW(vol->popup_window), 80, 140);
+    gtk_window_set_default_size(GTK_WINDOW(vol->popup_window), 80, scaling_factor*140);
     gtk_window_set_skip_taskbar_hint(GTK_WINDOW(vol->popup_window), TRUE);
     gtk_window_set_skip_pager_hint(GTK_WINDOW(vol->popup_window), TRUE);
     gtk_window_set_type_hint(GTK_WINDOW(vol->popup_window), GDK_WINDOW_TYPE_HINT_DIALOG);
