@@ -231,7 +231,7 @@ num2str(pair *p, int num, const gchar *defval)
     RET(defval);
 }
 
-int buf_gets( char* buf, int len, char **fp )
+static int buf_gets( char* buf, int len, char **fp )
 {
     char* p;
     int i = 0;
@@ -542,7 +542,7 @@ get_utf8_property_list(Window win, Atom atom, int *count)
         if (val[nitems-1]) {
             result = nitems - (s - val);
             DBG("val does not ends by 0, moving last %d bytes\n", result);
-            g_memmove(s - 1, s, result);
+            memmove(s - 1, s, result);
             val[nitems-1] = 0;
             DBG("s=%s\n", s -1);
             retval[i] = g_strdup(s - 1);
